notebook_shim: A shim layer for notebook traits and config
==========================================================

Description
-----------

A shim layer for notebook traits and config

License
-------

BSD 3-Clause License

Upstream Contact
----------------

https://pypi.org/project/notebook-shim/

